﻿using Syncfusion.Pdf.Graphics;
using Syncfusion.Windows.Forms.PdfViewer;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace TextSelectionDemo
{
    public partial class Form1 : Form
    {
        PdfViewerControl pdfViewerControl;
        string text = "";
        Point mouseLocation;
        PdfUnitConvertor unitConvertor = new PdfUnitConvertor();
        public Form1()
        {
            InitializeComponent();
            pdfViewerControl = new PdfViewerControl();
            this.Controls.Add(pdfViewerControl);
            pdfViewerControl.Dock = DockStyle.Fill;
            this.WindowState = FormWindowState.Maximized;
            pdfViewerControl.TextSelectionCompleted += PdfViewerControl_TextSelectionCompleted;
            pdfViewerControl.MouseDown += PdfViewerControl_MouseDown;
            pdfViewerControl.EnableContextMenu = false;
            CreateContextMenu();
        }
        /// <summary>
        /// Mouse down event to get the mouse current position where the text selection ends
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void PdfViewerControl_MouseDown(object sender, MouseEventArgs e)
        {
            if (e.Button == System.Windows.Forms.MouseButtons.Right)
                mouseLocation = e.Location;
        }
        /// <summary>
        /// To create context menu
        /// </summary>
        private void CreateContextMenu()
        {
            ContextMenuStrip menuStrip = new ContextMenuStrip();
            //To add copy context menu
            ToolStripMenuItem menuItem = new ToolStripMenuItem("Copy");
            menuItem.Click += new EventHandler(copy_Click);
            menuItem.Name = "Copy";
            menuStrip.Items.Add(menuItem);
            this.ContextMenuStrip = menuStrip;
            PointF currentPoint = unitConvertor.ConvertFromPixels(mouseLocation, PdfGraphicsUnit.Point);
            menuStrip.Show(Point.Round(currentPoint));
        }
        /// <summary>
        /// Copy click event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void copy_Click(object sender, EventArgs e)
        {
            ToolStripItem menuItem = (ToolStripItem)sender;
            if (menuItem.Name == "Copy")
            {
                Clipboard.SetText(text);
            }
        }
        /// <summary>
        /// Text selection completed event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="args"></param>
        private void PdfViewerControl_TextSelectionCompleted(object sender, TextSelectionCompletedEventArgs args)
        {
            text = args.SelectedText;
        }
        /// <summary>
        /// To 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button1_Click(object sender, EventArgs e)
        {
            List<TextData> result = new List<TextData>();
            pdfViewerControl.ExtractText(pdfViewerControl.CurrentPageIndex-1, out result);
            //if result.Count is zero, then there is not text in the page
            if (result.Count == 0)
                MessageBox.Show("No text content in the current page");
        }
    }
}
